/// <reference types="oracledb" />
import * as oracledb from 'oracledb';
import IConnection = oracledb.IConnection;
import IExecuteReturn = oracledb.IExecuteReturn;
import IExecuteOptions = oracledb.IExecuteOptions;
import IResultSet = oracledb.IResultSet;
import IConnectionAttributes = oracledb.IConnectionAttributes;
import { IConnectionPool } from "oracledb";
import { IDbService } from "./db_service";
export declare const DB_CONNECT_ERROR: string;
export declare const DB_ORACLE_ERROR: string;
export declare const DB_ORACLE_FETCH_ERROR: string;
export declare const DB_ORACLE_CLOSE_ERROR: string;
export declare const DB_ORACLE_RELEASE_ERROR: string;
export declare const DB_ORACLE_EXECUTE_ERROR: string;
export declare class OracleService implements IDbService {
    poolMax: number;
    maxQueryAttempts: number;
    protected connectionParams: IConnectionAttributes;
    protected options: IExecuteOptions;
    protected pool: IConnectionPool;
    protected _queryFailsCounter: any;
    constructor(connectionParams: IConnectionAttributes, options?: IExecuteOptions);
    run(query: string, params?: Array<any>, options?: IExecuteOptions): Promise<IExecuteReturn>;
    getManyRows(query: string, params?: Array<any>): Promise<IExecuteReturn>;
    fetchRows(resultSet: IResultSet, numRows: number): Promise<Array<any>>;
    closeResultSet(resultSet: IResultSet, connection?: IConnection): Promise<void>;
    getRows(query: string, params?: Array<any>, options?: IExecuteOptions): Promise<Array<any>>;
    getRow(query: string, params?: Array<any>, options?: IExecuteOptions): Promise<any>;
    mustGetRow(errorCode: string, query: string, params?: Array<any>, options?: IExecuteOptions): Promise<any>;
    protected _connect(): Promise<IConnection>;
    protected _disconnect(connection: IConnection): Promise<void>;
    protected _run(query: string, params?: object | Array<any>, options?: IExecuteOptions): Promise<IExecuteReturn>;
    protected _needRetry(runArguments: IArguments, error: any): boolean;
}
