"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_1 = require("./helpers");
const logger_1 = require("../logger");
const __1 = require("../..");
const traceSpanLogger = logger_1.getLogger({ logLevel: logger_1.DEFAULT_LOG_LEVEL });
function TraceSpan(target, propertyKey, descriptor) {
    const method = descriptor.value || target;
    const wrapper = function () {
        const currentTrace = __1.ClsService.getTrace();
        if (currentTrace) {
            currentTrace.span();
        }
        traceSpanLogger.info('Start', helpers_1.getClassAndMethodName(this, propertyKey));
        let err;
        let isAsync = false;
        try {
            const methodResult = method.apply(this, arguments);
            if (methodResult && methodResult.then) {
                isAsync = true;
                methodResult.then(() => {
                    traceSpanLogger.info('End success', helpers_1.getClassAndMethodName(this, propertyKey));
                }).catch((err) => {
                    traceSpanLogger.info('End errored', helpers_1.getClassAndMethodName(this, propertyKey), err);
                });
            }
            return methodResult;
        }
        catch (e) {
            err = e;
            throw err;
        }
        finally {
            if (!isAsync) {
                if (err) {
                    traceSpanLogger.info('End errored', helpers_1.getClassAndMethodName(this, propertyKey), err);
                }
                else {
                    traceSpanLogger.info('End success', helpers_1.getClassAndMethodName(this, propertyKey));
                }
            }
        }
    };
    descriptor.value = wrapper;
    return wrapper;
}
exports.TraceSpan = TraceSpan;
