"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const joi = require("joi");
const validation_1 = require("../../error/validation");
const _ = require("lodash");
const camelCase = require("camelcase-object");
const validator = require("validator");
const customJoi = joi.extend((joi) => ({
    base: joi.string(),
    name: 'string',
    pre(value, state, options) {
        if (options.convert) {
            return validator.escape(value);
        }
        return value;
    }
})).extend((joi) => ({
    base: joi.string(),
    name: 'unescapedString',
    pre(value, state, options) {
        return validator.unescape(value);
    }
}));
exports.customJoi = customJoi;
const defaultOptions = {
    stripUnknown: true
};
function getRequestParamsFromContext(ctx) {
    let params;
    if (ctx.request.method === 'GET') {
        params = ctx.request.query;
    }
    else {
        const contentType = ctx.req.headers['content-type'];
        if (!contentType || contentType.indexOf('application/json') > -1) {
            params = ctx.request.body;
        }
        else if (contentType.indexOf('multipart/form-data') > -1 && ctx.request.body.fields) {
            params = ctx.request.body.fields;
        }
        else {
            params = ctx.request.body;
        }
        params = Object.assign({}, params, ctx.params);
    }
    return params;
}
exports.getRequestParamsFromContext = getRequestParamsFromContext;
function createValidationMiddleware(schema) {
    return function (ctx, next) {
        return __awaiter(this, void 0, void 0, function* () {
            const requestParams = getRequestParamsFromContext(ctx);
            const result = customJoi.validate(requestParams, schema, defaultOptions);
            if (result.error) {
                const type = _.get(result.error, 'details.0.type');
                const invalidKey = _.get(result.error, 'details.0.path.0');
                const invalidValue = requestParams[invalidKey];
                const message = _.get(result.error, 'details.0.message');
                throw new validation_1.ValidationError(validation_1.ValidationError.DEFAULT, invalidKey, invalidValue, message, type);
            }
            ctx.validatedData = {
                originalCase: result.value,
                camelCase: camelCase(result.value)
            };
            yield next();
        });
    };
}
exports.createValidationMiddleware = createValidationMiddleware;
