"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const log4js = require("log4js");
const cls_service_1 = require("./services/cls_service");
exports.DEFAULT_LOG_LEVEL = 'TRACE';
function createLoggerJsonLayout(appConfig) {
    log4js.addLayout('json', (loggerConfig) => {
        return (logEvent) => {
            const loggedObject = {
                startTime: logEvent.startTime,
                level: logEvent.level.levelStr,
                application: appConfig.appName,
                mdc: cls_service_1.ClsService.getTrace(),
                message: logEvent.data.map((data) => typeof data === "object" ? JSON.stringify(data) : data)
            };
            return JSON.stringify(loggedObject);
        };
    });
}
exports.createLoggerJsonLayout = createLoggerJsonLayout;
function configureLogger(appConfig) {
    log4js.configure({
        appenders: {
            out: {
                type: 'stdout',
                layout: {
                    type: 'json'
                }
            }
        },
        categories: {
            default: { appenders: ['out'], level: appConfig.logLevel || exports.DEFAULT_LOG_LEVEL }
        },
        pm2: appConfig.pm2
    });
}
exports.configureLogger = configureLogger;
function getLogger(config) {
    createLoggerJsonLayout(config);
    configureLogger(config);
    return log4js.getLogger();
}
exports.getLogger = getLogger;
function replaceConsoleWithLogger(logger) {
    console.log = logger.log.bind(logger);
    console.trace = logger.trace.bind(logger);
    console.debug = logger.debug.bind(logger);
    console.warn = logger.warn.bind(logger);
    console.error = logger.error.bind(logger);
}
exports.replaceConsoleWithLogger = replaceConsoleWithLogger;
