"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const validator = require("validator");
const validation_1 = require("../error/validation");
class Validator {
    static isInt(value, min = Number.MIN_SAFE_INTEGER, max = Number.MAX_SAFE_INTEGER) {
        value = Validator.isNumber(value, min, max);
        if (!validator.isInt(value.toString())) {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_INT);
        }
        return value;
    }
    static isNumber(value, min = Number.MIN_SAFE_INTEGER / 128, max = Number.MAX_SAFE_INTEGER / 128) {
        value = parseFloat(Validator.isString(value));
        if (!isNaN(value)) {
            if (value >= min && value <= max) {
                return value;
            }
            throw new validation_1.ValidationError(validation_1.ValidationError.NUMBER_OUT_OF_BOUNDS);
        }
        throw new validation_1.ValidationError(validation_1.ValidationError.NO_NUMBER);
    }
    static escape(value) {
        return validator.escape(value || '');
    }
    static isString(value, min = 1, max = 256) {
        if (typeof value === 'number') {
            value = value.toString();
        }
        if (typeof value === 'string') {
            const processedValue = value.trim();
            if (processedValue.length >= min && processedValue.length <= max) {
                return Validator.escape(processedValue);
            }
            throw new validation_1.ValidationError(validation_1.ValidationError.STRING_OUT_OF_BOUNDS);
        }
        throw new validation_1.ValidationError(validation_1.ValidationError.NO_STRING);
    }
    static isEmail(value) {
        const email = Validator.isString(value).toLowerCase();
        if (validator.isEmail(email)) {
            return email;
        }
        else {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_EMAIL);
        }
    }
    static isArray(array, iterator) {
        if (!(array instanceof Array) || array.length === 0) {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_ARRAY);
        }
        if (typeof iterator === 'function') {
            return array.map((el) => iterator(el));
        }
        return array;
    }
    static isDate(value, min, max) {
        const strDate = Validator.isString(value);
        if (!strDate) {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_DATE);
        }
        const isISO8601 = validator.isISO8601(strDate);
        if (!isISO8601) {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_DATE);
        }
        const date = new Date(strDate);
        if (isNaN(date.getTime())) {
            throw new validation_1.ValidationError(validation_1.ValidationError.NO_DATE);
        }
        if (min instanceof Date && date.getTime() < min.getTime()) {
            throw new validation_1.ValidationError(validation_1.ValidationError.DATE_OUT_OF_BOUNDS);
        }
        if (max instanceof Date && date.getTime() > max.getTime()) {
            throw new validation_1.ValidationError(validation_1.ValidationError.DATE_OUT_OF_BOUNDS);
        }
        return date;
    }
}
exports.Validator = Validator;
